@@ -1,8 +1,8 @@
 import numpy as np
 import pytest
-from spotPython.fun.objectivefunctions import analytical
-from spotPython.spot import spot
-from spotPython.utils.init import fun_control_init, design_control_init
+from spotpython.fun.objectivefunctions import analytical
+from spotpython.spot import spot
+from spotpython.utils.init import fun_control_init, design_control_init
 
 
 @pytest.fixture
